
# Type: has gene product


holds between a gene and a transcribed and/or translated product generated from it

URI: [biolink:has_gene_product](https://w3id.org/biolink/vocab/has_gene_product)


## Domain and Range

[Gene](Gene.md) ->  <sub>0..*</sub> [GeneProduct](GeneProduct.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [Gene](Gene.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002205 |
|  | | WD:P688 |
| **In Subsets:** | | translator_minimal |

